biosimulators_utils.viz.vega.sbgn package — BioSimulators utils 0.1.154 documentation

# biosimulators_utils.viz.vega.sbgn package

## Submodules

## biosimulators_utils.viz.vega.sbgn.core module

Utility for converting activity SBGN process description (PD) maps to Vega format

Author

  Andrew Freiburger <afreiburger@uvic.ca>

Author

  Jonathan Karr <karr@mssm.edu>

Date

  2021-08-11

Copyright

  2021, Center for Reproducible Biomedical Modeling

License

  MIT

biosimulators_utils.viz.vega.sbgn.core.sbgn_pd_map_to_vega(glyph_values_data_set, sbgn_filename, vega_output_filename, max_width=700, max_height=700, indent=2)

  Convert a process description (PD) map from SBGN to Vega format.

  Parameters

    - glyph_values_data_set (`dict`) –

      Vega data set with the predicted dynamics of one or more glyphs. The dictionary should have one of the following schemas

      - Contain a key `values` whose value is a list of the predicted values of the glyphs. Each element of the list should be a dictionary with two keys

        > - `label`: value should be the SBGN `label` of the corresponding glyph

        > - `values`: array of the predicted values of the glyph

      - Contain a key `url` whose value is a URL where the predicted values of the glyphs can be retrieved in JSON format. The data should be in the same format outlined above.

      - Contain a key `sedmlUri` whose value is an array which contains two elements that indicate

        > - The location of the SED-ML file (within its parent COMBINE/OMEX archive) which will produce the predicted values of the glyphs

        > - The id of the SED-ML report which will contain the predicted values of the glyphs for the visualization

    - sbgn_filename (`str`) – the name of the SBGN file that will be parsed

    - vega_output_filename (`str`) – path to the ginsim simulation data

    - max_width (`int`) – maximum diagram width

    - max_height (`int`) – maximum diagram height

    - indent (`int` or `None`, optional) – indentation for exported Vega file